function panoramicImage = panoramic (circularImage, xC, yC, xMin, xMax, yMax, M, N, shift)
%Function PANORAMIC converts a circular image to panoramic.
%panoramicImage=panoramic(circularImage, xC, yC, xMin, xMax, yMax, M, N, shift)
%where circularImage contains the wrapped image, xC and yC are the
%coordinates of the center of the wrapped image, xMin and  xMax are the 
%radiances of the inner and outer circle [in pixels] for the X dimension, 
%and yMax is the radiance of the outer circle [in pixels] for the Y dimension.
%MxN are the dimensions of the unwrapped panoramic image. Parameter shift
%is a correction term for aligning the middle of the picture. X and Y 
%dimensions are defined as the matrix and not the image dimensions, thus they
%are the inverse of what you see in the image.
%Example: 
%panoramicImage = panoramic(circularImage, 293, 401, 103, 265, 244, 100,
%600, -1.6)
%
%To keep the code small & fast, no check on the input values is performed. 
%Please make sure that you enter appropriate values. For the same reason, 
%no interpolation technique is applied.
%
%The function is based on Im2Polar.m function V0.1 7 Dec 2007 created by 
%Prakash Manandhar, pmanandhar@umassd.edu, available from Matlab Central
%under the description Polar To/From Rectangular Transform of Images
%Modified by Eleni Vasilaki, LCN Lab, on Jan 2008 to unwrap images taken by
%the 2D 360 degrees vision turret of a Khepera Robot. 
 
    panoramicImage = zeros(M, N);
    rMax=1;
    rMin=xMin/xMax;
 
    dx = (rMax - rMin)/(M-1);
    dy = 2*pi/N;

    for xi = 0:M-1
        for yi = 0:N-1
            r = rMin + xi*dx;
            theta = yi*dy+shift;
            x = round(r*cos(theta)*xMax+xC);
            y = round(r*sin(theta)*yMax+yC);
            panoramicImage (M-xi, yi+1) = circularImage(x,y);
        end
    end
end



